@@ -1,8 +1,9 @@
+# -*- coding: iso-8859-1 -*-
 """
 Some common declarations for the xmlproc system gathered in one file.
 """
 
-# $Id: xmlutils.py,v 1.31 2002/01/13 20:55:03 loewis Exp $
+# $Id: xmlutils.py,v 1.34 2002/09/13 15:37:17 fdrake Exp $
 
 import string,re,urlparse,os,sys,types
 
@@ -161,7 +162,9 @@ class EntityParser:
         tmp = self.seen_xmldecl
         self.seen_xmldecl = 0 # Avoid complaints
 
-        self.read_from(inf)
+        # XXX Should not need to read the whole thing in, but doing so
+        # fixes PyXML SF bug #608453.  There should be a better fix.
+        self.read_from(inf, -1)
 
         self.seen_xmldecl = tmp
         self.flush()
@@ -678,7 +681,7 @@ class XMLCommonParser(EntityParser):
                 self.report_error(3902)
             enc = string.lower(enc)
             if self.input_encoding and self.input_encoding!=enc:
-                self.report_error(3047)
+                self.report_error(3047, enc)
 
             self.skip_ws()
 
@@ -717,6 +720,7 @@ class XMLCommonParser(EntityParser):
             # to the recoding.
             try:
                 self.data = self.charset_converter(self.data)
+                self.datasize = len(self.data)
             except UnicodeError, e:
                 self._handle_decoding_error(self.data, e)
             self.input_encoding = enc1
