@@ -2,7 +2,6 @@
 #
 # File Name:            Stylesheet.py
 #
-# Documentation:        http://docs.4suite.com/4XSLT/Stylesheet.py.py.html
 #
 """
 Implement all the stylesheet internals
@@ -13,7 +12,6 @@ See  http://4suite.com/COPYRIGHT  for license and copyright information
 """
 
 import string, types
-import urlparse, urllib
 from xml.dom import EMPTY_NAMESPACE
 import xml.dom.ext
 from xml import xpath, xslt
@@ -375,8 +373,8 @@ class StylesheetElement(XsltElement):
 
         #Attribute sets
         attribute_sets = filter(lambda x: x.nodeType == Node.ELEMENT_NODE and (x.namespaceURI, x.localName) == (XSL_NAMESPACE, 'attribute-set'), self.childNodes)
-        for as in attribute_sets:
-            as.instantiate(context, processor)
+        for a_s in attribute_sets:
+            a_s.instantiate(context, processor)
         overridden_params = {}
         for k in topLevelParams.keys():
             if type(k) != types.TupleType:
